@@ -34,37 +34,39 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QPainter>
 
-struct Shortcut{
+struct Shortcut {
     QString name;
     QString value;
     int nameLength;
     int valueLength;
     int y;
 };
-struct Column{
-    int x=0;
-    int width=0;
+struct Column {
+    int x = 0;
+    int width = 0;
 };
 
 class ShortcutScene : public QGraphicsScene
 {
 public:
     ShortcutScene(QObject *parent);
-    ShortcutScene(QObject *parent , QString data , int flag);
+    ShortcutScene(QObject *parent, QString data, int flag);
     void initUI();
     void initData();
     void sortData();
     void loadFile(QString file);
 
+    QString languageTest();
 private:
-    QList<Shortcut>* m_displayShortcutLists[3];
+    QList<Shortcut> *m_displayShortcutLists[3];
     QList<Shortcut> m_shortcutList;
-    int m_maxContentHeigth=0;
-    int m_maxContentWidth=0;
-    QList<QGraphicsTextItem*>* m_listTextItems[6];
+    int m_maxContentHeigth = 0;
+    int m_maxContentWidth = 0;
+    QList<QGraphicsTextItem *> *m_listTextItems[6];
     Column m_cols[6];
-    const int m_startx=0;
-    const int m_starty=0;
+    const int m_startx = 0;
+    const int m_starty = 0;
+    QString m_lang;
 };
 
 #endif // SHORTCUTSCENE_H
